Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1)

Unified Diff: cloud_print/virtual_driver/win/port_monitor/port_monitor.h

Issue 10687007: Added Chrome profile option in registry. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cloud_print/virtual_driver/win/port_monitor/port_monitor.h
diff --git a/cloud_print/virtual_driver/win/port_monitor/port_monitor.h b/cloud_print/virtual_driver/win/port_monitor/port_monitor.h
index e9e83f0bcae146ad2d50de58ab541be119d484d8..05df124cf8647324d025481b60a26379ce97edeb 100644
--- a/cloud_print/virtual_driver/win/port_monitor/port_monitor.h
+++ b/cloud_print/virtual_driver/win/port_monitor/port_monitor.h
@@ -14,8 +14,11 @@
namespace cloud_print {
-// Fills chrome_path with the path to be used for launching Chrome.
-bool GetChromeExePath(FilePath* chrome_path);
+// Returns path to be used for launching Chrome.
+FilePath GetChromeExePath();
+
+// Returns path to user profile to be used for launching Chrome.
+FilePath GetChromeProfilePath();
// Implementations for the function pointers in the MONITOR2 structure
// returned by InitializePrintMonitor2. The prototypes and behaviors
@@ -79,7 +82,8 @@ BOOL WINAPI MonitorUiConfigureOrDeletePortUI(const wchar_t*,
const wchar_t* port_name);
extern const wchar_t kChromeExePath[];
-extern const wchar_t kChromePathRegValue[];
+extern const wchar_t kChromeExePathRegValue[];
+extern const wchar_t kChromeProfilePathRegValue[];
extern const bool kIsUnittest;
} // namespace cloud_print
« no previous file with comments | « cloud_print/virtual_driver/win/install/setup.cc ('k') | cloud_print/virtual_driver/win/port_monitor/port_monitor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698